@@ -13,7 +13,10 @@ import cdk8s_plus_17._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk8s-redis-sts", "0.0.1", __name__[0:-6], "cdk8s-redis-sts@0.0.1.jsii.tgz"
+    "@Hunter-Thompson/cdk8s-redis-sts",
+    "0.0.2",
+    __name__[0:-6],
+    "cdk8s-redis-sts@0.0.2.jsii.tgz",
 )
 
 __all__ = [
